@@ -1,23 +1,20 @@
 from jaseci.svc import (
     CommonService,
+    ApplicationContext,
     MetaProperties,
     MailService,
     RedisService,
-    ServiceState as Ss,
     TaskService,
     KubernetesService,
     PromotheusService,
     JsOrcService,
 )
 
-from jaseci.utils.utils import logger
-
 
 class MetaService(CommonService, MetaProperties):
     def __init__(self, run_svcs=True):
         self.run_svcs = run_svcs
         MetaProperties.__init__(self, __class__)
-        CommonService.__init__(self)
 
         self.start()
 
@@ -26,53 +23,43 @@ class MetaService(CommonService, MetaProperties):
     ###################################################
 
     def run(self, hook=None):
-        self.build_classes()
-        self.build_services()
-        self.state = Ss.RUNNING
+        self.app = ApplicationContext()
+        self.populate_context()
+        self.populate_services()
 
     ###################################################
     #                    SERVICES                     #
     ###################################################
 
-    # args & kwargs will be used as *args & **kwargs on initialization
     def add_service_builder(self, name, svc):
-        if self.services.get(name):
-            raise Exception(f"{name} already exists!")
-
-        self.services[name] = svc
+        self.app.add_service_builder(name, svc)
 
     def build_service(self, name, background, *args, **kwargs):
-
-        svc = self.services.get(name)
-
-        if not svc:
-            logger.error(f"Service {name} is not yet set!")
-            return None
-
-        svc = svc(*args, **kwargs)
-
-        if background:
-            self.background[name] = svc
-
-        return svc
+        return self.app.build_service(name, background, *args, **kwargs)
 
     def get_service(self, name, *args, **kwargs):
-        svc = self.background.get(name)
+        return self.app.get_service(name, *args, **kwargs)
 
-        if not svc:
-            return self.build_service(name, True, *args, **kwargs)
+    ###################################################
+    #                    CONTEXT                      #
+    ###################################################
 
-        return svc
+    def add_context(self, ctx, cls, *args, **kwargs):
+        self.app.add_context(ctx, cls, *args, **kwargs)
+
+    def build_context(self, ctx, *args, **kwargs):
+        return self.app.build_context(ctx, *args, **kwargs)
+
+    def get_context(self, ctx):
+        return self.app.context.get(ctx, {}).get("class")
 
     ###################################################
     #                     BUILDER                     #
     ###################################################
 
     def build_hook(self):
-        params = self.hook_param
-        h = self.hook(*params.get("args", []), **params.get("kwargs", {}))
+        h = self.build_context("hook")
         h.meta = self
-
         if self.run_svcs:
             h.kube = self.get_service("kube", h)
             h.jsorc = self.get_service("jsorc", h)
@@ -94,36 +81,31 @@ class MetaService(CommonService, MetaProperties):
         return h
 
     def build_master(self, *args, **kwargs):
-        return self.__common(self.master, *args, **kwargs)
+        return self.__common("master", *args, **kwargs)
 
     def build_super_master(self, *args, **kwargs):
-        return self.__common(self.super_master, *args, **kwargs)
-
-    def __common(self, cls, *args, **kwargs):
+        return self.__common("super_master", *args, **kwargs)
 
+    def __common(self, ctx, *args, **kwargs):
         if not kwargs.get("h", None):
             kwargs["h"] = self.build_hook()
 
-        return cls(*args, **kwargs)
+        return self.build_context(ctx, *args, **kwargs)
 
     ###################################################
     #                   OVERRIDEN                     #
     ###################################################
 
-    def build_classes(self):
+    def populate_context(self):
         from jaseci.hook import RedisHook
         from jaseci.element.master import Master
         from jaseci.element.super_master import SuperMaster
 
-        self.hook = RedisHook
-        self.hook_param = {
-            "args": [],  # override to add arg
-            "kwargs": {},  # override to add field
-        }
-        self.master = Master
-        self.super_master = SuperMaster
+        self.add_context("hook", RedisHook)
+        self.add_context("master", Master)
+        self.add_context("super_master", SuperMaster)
 
-    def build_services(self):
+    def populate_services(self):
         self.add_service_builder("redis", RedisService)
         self.add_service_builder("task", TaskService)
         self.add_service_builder("mail", MailService)
